/**************************************************************************************************
	Developed by: the Colorado Health Institute (CHI)
	Contact Information: 
		Glenn Goodrich
		303-831-4200 x225
		goodrichg@coloradohealthinstitute.org

	The 2008 Registered Nurse PUF data file was created with a 64-bit  
	version of SAS 9.2 on a 64-bit MS Windows operating system. If this data file will be 
	used with a 32-bit version of SAS 9.2 or earlier, the data file needs to be reassigned, 
	through a DATA STEP, so that it can subsequently assign the SAS formats correctly.

	The following code will execute the necessary DATA STEP described above and then assign 
	the SAS formats to the variables included in the RN PUF. 

	INPUT: rn08_puf.sas7bdat (64-bit SAS 9.2 data file from CHI)
	OUTPUT: a data file compatible with the user's version of SAS, with its associated SAS formats 

	NOTATION:
		>> USER INPUT <<;
		indicates all places in the beginning of the code where the user 
		should input information.
	
***************************************************************************************************/
options mprint mlogic symbolgen;
%global filename lib fmtlib;

************************** USER INPUT REQUIRED FOR THIS SECTION ONLY *******************************;

*>> USER INPUT <<;
* INSTRUCTIONS: provide a name for the SAS library associated with the location of the final 
* version of the data file
* (Example: lib = Survey);
%let lib = ;

*>> USER INPUT <<;
* INSTRUCTIONS: directory pathname for where the final version of the data file will be stored
* (Example: "C:\MyData");
libname &lib. "";

*>> USER INPUT <<;
* INSTRUCTIONS: name for FINAL version of the data file (it must have a different filename 
* than the CHI version if it will be stored in the SAME directory)
* (Example: filename = SurveyData);
%let filename = ;


*>> USER INPUT <<;
* INSTRUCTIONS: directory path name for where the CHI version of the PUF data file is located
* (Example: "C:\MyData\CHI");
libname LIB1 "";

*>> USER INPUT <<;
* INSTRUCTIONS: name for SAS library where the formats with be stored 
* (Example: fmtlib = rnfmt);
%let fmtlib = ;

*>> USER INPUT <<;
* INSTRUCTIONS: directory pathname for where format catalog will be stored
* (Example: "C:\MyData\Formats");
libname &fmtlib. "";

***************************************** END USER INPUT ******************************************
***************************************************************************************************;


options fmtsearch=(&fmtlib.);

* this DATA STEP will restructure the SAS data file to be compatible with user's version of SAS;
data &lib..&filename.; set lib1.rn08_puf; run;
proc format library=&fmtlib.;
value $rn8st
'-9'		="Missing"
'-8'		=">Not Applicable<"
'-7'		='>Skip pattern violation<'
'-6'		='>Invalid answer/out of range<'
'AA'		="Armed Forces -Americas"
'AE'		="Armed Forces -Europe, Canada, Africa, Middle East"
'AK'		="Alaska"
'AL'		="Alabama"
'AP'		="Armed Forced -Pacific"
'AR'		="Arkansas"
'AS'		="American Samoa"
'AZ'		="Arizona"
'CA'		="California"
'CO'		="Colorado"
'CT'		="Connecticut"
'CM' 		="Northern Mariana Islands"
'MP'		="Northern Mariana Islands"
'DC'		="District of Columbia"
'DE'		="Delaware"
'FL'		="Florida"
'FM'		="Federated States of Micronesia"
'FO'		="Foreign Country"
'GA'		="Georgia"
'GU'		="Guam"
'HI'		="Hawaii"
'IA'		="Iowa"
'ID'		="Idaho"
'IL'		="Illinois"
'IN'		="Indiana"
'KS'		="Kansas"
'KY'		="Kentucky"
'LA'		="Louisiana"
'MA'		="Massachusetts"
'MD'		="Maryland"
'ME'		="Maine"
'MH'		="Marshall Islands"
'MI'		="Michigan"
'MN'		="Minnesota" 
'MO'		="Missouri"    
'MS'		="Mississippi"
'MT'		="Montana"
'NC'		="North Carolina"
'ND'		="North Dakota"
'NE'		="Nebraska"
'NH'		="New Hampshire"
'NJ'		="New Jersey"
'NM'		="New Mexico"
'NV'		="Nevada"
'NY'		="New York"
'OH'		="Ohio"
'OK'		="Oklahoma"
'OR'		="Oregon"
'PA'		="Pennsylvania"
'PR'		="Puerto Rico"
'PW'		="Palau"
'RI'		="Rhode Island"
'SC'		="South Carolina"
'SD'		="South Dakota"
'TN'		="Tennessee"
'TX'		="Texas"
'UT'		="Utah"
'VA'		="Virginia"
'VI'		="US Virgin Islands"
'VT'		="Vermont"
'WA'		="Washington"
'WI'		="Wisconsin"
'WV'		="West Virginia"
'WY'		="Wyoming"
'XX'		="Foreign Country"
other		=[$2.]
;
value ageg08rn
-9 = "Missing"
-8 = ">Not Applicable<"
-7 = ">Skip pattern violation<"
-6 = ">Invalid answer/out of range<"
1 = "34 years or younger"
2 = "35 - 44 years"
3 = "45 - 54 years"
4 = "55 - 64 years"
5 = "65 years or older"
;
value gage08rn
-9 = "Missing"
-8 = ">Not Applicable<"
-7 = ">Skip pattern violation<"
-6 = ">Invalid answer/out of range<"
1 = "25 years or younger"
2 = "26 - 35 years"
3 = "36 years or older"
;
value grdg08rn
-9 = "Missing"
-8 = ">Not Applicable<"
-7 = ">Skip pattern violation<"
-6 = ">Invalid answer/out of range<"
1 = "5 years or less"
2 = "6 - 15 years"
3 = "16 - 25 years"
4 = "26 - 35 years"
5 = "36 - 45 years"
6 = "46 years or more"
;
value rn08acpg_grp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Baccalaureate or lower'
2			='Master''s or higher'
;
value rn08agrgrp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
0			='Indifferent or disagree (1,2,3)'
1			='Agree (4,5)'
2			='N/A'
;
value rn08barr
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
0			='Barrier'
1			='Not a Barrier'
;
value rn08cgrp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Urban'
2			='Rural'
3			='Suburban'
;
value rn08facl
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Yes'
2			='No'
3			='Undecided'
4			='Already faculty member'
;
value rn08focngp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Medical/surgical care'
2			='Ambulatory care'
3			='Critical care'
4			='Pediatric care'
5			='Obstetrical care'
6			='Oncology'
7			='Psychiatric care'
8			='Geriatric care'
9			='Emergency care'
10			='Prevention/wellness'
11			='Nurse administrator'
12			='Case manager'
13			='Nurse educator'
14			='Other'
;
value rn08gend
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Male'
2			='Female'
;
value rn08incgp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='$25,000 or less'
2			='$25,001 to $50,000'
3			='$50,001 to $75,000'
4			='$More than 75,001'
5			='Not working'
;
value rn08spdegp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='To supplement the earnings from my fulltime or partime nursing position'
2			='No fulltime wk offered, gain experience, enjoy different nsg pos, other'
;
value rn08tpstgp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Acute care facility'
2			='Nursing home/extended care facility'
3			='Home health care agency'
4			='Public/community health nurse'
5			='Private physician office'
6			='Federal, state or local governmental agency'
7			='Ambulatory surgical center'
8			='Other'
;
value rn08tspngp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
0			='Little time or indifferent (1,2,3)'
1			='Too much time (4,5)'
2			='N/A'
;
value rn8_educgp
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
1='High School Diploma'
2='Associate Degree'
3='Baccalaureate/Master/Doctorate Degree'
4='LPN or CNA Program'
;
value rn8_poexgp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
0			='Indifferent or Excellent'
1			='Poor, levels 1 or 2'
2			='N/A'
;
value rn8bsedgrp
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
1			='Diploma'
2			='Associate Degree'
3			='Baccalaureate Degree or higher'
;
value rn8inoti
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
0			='Important'
1			='Not important'
;
value rn8yesno
-9			='Missing'
-8			='>Not Applicable<'
-7			='>Skip pattern violation<'
-6			='>Invalid answer/out of range<'
0			='No'
1			='Yes'
;
value rnbyrgp
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
1='1943 or before'
2='1944-1953'
3='1954-1963'
4='1964-1973'
5='1974 or after'
;
value rngrstgp
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
0='Non-Colorado'
1='Colorado'
;
value rngryrgp
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
1		='1970 or before'
2		='1971-1980'
3		='1981-1990'
4		='1991-2000'
5		='2001 or after'
;
value rnhousnm
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
1='One'
2='Two'
3='Three'
4='Four or more'
;
value rnhradd
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
1='0-8 hours'
2='9-16 hours'
3='Greater than 16 hours'
;
value rnhrwkgp
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
1='0-24 hours'
2='25-36 hours'
3='37-40 hours'
4='Greater than 40 hours'
;
value rnhrwkgp
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
1='0-24 hours'
2='25-36 hours'
3='37-40 hours'
4='Greater than 40 hours'
;
value rnprposgrp
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
1='Employee of the organization or facility'
2='Employed through temp/traveling agency or self-employed'
;
value rnrucgp
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
1='Isolated'
2='Rural Small'
3='Rural Large'
4='Urban'
;
value rnwhite
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
0='Non-white'
1='White'
;
value rnyrwkgp
-9='Missing'
-8='>Not Applicable<'
-7='>Skip pattern violation<'
-6='>Invalid answer/out of range<'
1='0-5 years'
2='6-15 years'
3='16-25 years'
4='26-35 years'
5='36 years or more'
;
value urban8rn
-9 = "Missing"
-8 = ">Not Applicable<"
-7 = ">Skip pattern violation<"
-6 = ">Invalid answer/out of range<"
0		="Rural"
1		="Urban"
;
run;
proc datasets library = &lib.;
	modify &filename.;
	format primary_state_from_zip $RN8ST.;
	format age_grp AGEG08RN.;
	format grad_age_grp GAGE08RN.;
	format grad_numyrs_grp GRDG08RN.;
	format enrolled_grp RN08ACPG_GRP.;
	format no_enroll_no_interest_grp no_enroll_afford_grp no_enroll_time_commit_grp no_enroll_close_to_home_grp 
	no_enroll_attained_educ_grp orient_both_grp orient_clinical_grp orient_individual_grp orient_preceptor_grp 
	orient_time_grp no_work_safety_grp no_work_stress_grp no_work_overtime_grp no_work_hours_grp no_work_wages_grp 
	no_work_fringe_benefits_grp no_work_respect_grp no_work_health_grp no_work_family_grp no_work_retired_grp 
	no_work_rn_lic_not_needed_grp prim_rns_valued_grp prim_document_grp prim_member_grp prim_salary_grp 
	prim_staffing_grp prim_pos_relation_grp prim_hours_grp prim_supportive_grp prim_excellence_grp 
	prim_career_develop_grp prim_appropriate_orient_grp prim_high_quality_grp prim_cultural_grp 
	prim_workload_grp plans_current_employ_grp plans_retire_grp plans_advance_grp plans_advanced_degree_grp
	plans_traveling_nurse_grp plans_nurse_admin_grp plans_apn_grp plans_comm_nurse_grp plans_faculty_grp 
	leave_rsn_safety_grp leave_rsn_stress_grp leave_rsn_overtime_grp leave_rsn_hours_grp leave_rsn_wages_grp 
	leave_rsn_benefits_grp leave_rsn_respect_grp leave_rsn_challenge_grp RN08AGRGRP.;
	format prevent_faculty_time prevent_faculty_tuition prevent_faculty_income prevent_faculty_info 
	prevent_faculty_finance prevent_faculty_rural prevent_faculty_no_interest RN08BARR.;
	format grewup RN08CGRP.;
	format interest_faculty RN08FACL.;
	format focus_grp RN08FOCNGP.;
	format gender RN08GEND.;
	format income_grp RN08INCGP.;
	format rsn_grp RN08SPDEGP.;
	format setting_grp RN08TPSTGP.;
	format time_patient_care_grp RN08TSPNGP.;
	format time_notes_grp time_supplies_grp time_transport_grp time_phonecalls_grp time_meetings_grp 
	time_shift_change_grp RN08TSPNGP.;
	format educ_level_grp RN8_EDUCGP.;
	format classroom_elderly_grp classroom_dementia_grp classroom_phys_dis_grp classroom_behave_grp 
	classroom_pat_assess_grp classroom_leader_grp classroom_prob_solve_grp classroom_rn_role_grp 
	classroom_cultural_grp clinical_nursing_home_grp clinical_acute_care_grp clinical_public_health_grp 
	clinical_comm_health_grp clinical_operating_room_grp clinical_psych_grp clinical_simul_dvd_grp 
	clinical_simul_mann_grp clinical_simulation_web_grp clinical_rn_role_grp RN8_POEXGP.;
	format rn_program_grp RN8BSEDGRP.;
	format inc_faculty_flex inc_faculty_loan inc_faculty_accel 
	inc_faculty_credit inc_faculty_scholar inc_faculty_tuit_asst RN8INOTI.;
	format since_grad_assoc since_grad_bacc_nurs since_grad_bacc_non since_grad_masters_nurs 
	since_grad_masters_non since_grad_other enrolled_educ_prog cert_crna cert_acute 
	cert_pop cert_other_spec cert_primary cert_other_prac cert_spec apn employed_co 
	another_position leave_12months fluent prim_wage_earner encourage_nursing RN8YESNO.;
	format birth_year_grp RNBYRGP.;
	format grad_state_grp RNGRSTGP.;
	format grad_year_grp RNGRYRGP.;
	format num_in_household_grp RNHOUSNM.;
	format another_position_hours_grp RNHRADD.;
	format hours_week_grp hours_patient_care_grp RNHRWKGP.;
	format primary_position_grp RNPRPOSGRP.;
	format primary_ruca2_from_zip_grp home_ruca2_from_zip_grp RNRUCGP.;
	format ethwhite RNWHITE.;
	format years_worked_rn_grp RNYRWKGP.;
	format primary_urban_from_zip home_urban_from_zip URBAN8RN.;
quit;
